@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-table-config.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -33,12 +33,10 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <gtk/gtkdialog.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtklabel.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtksignal.h>
 #include <gtk/gtktogglebutton.h>
-#include <libgnomeui/gnome-dialog.h>
 #include <libgnomeui/gnome-propertybox.h>
 #include <glade/glade.h>
 #include "gal/util/e-util.h"
@@ -50,9 +48,7 @@
 #include <e-table-memory-store.h>
 
 
-#define PARENT_TYPE (gtk_object_get_type())
-
-static GtkObjectClass *config_parent_class;
+static GObjectClass *config_parent_class;
 
 enum {
 	CHANGED,
@@ -60,20 +56,29 @@ enum {
 };
 
 enum {
-	ARG_0,
-	ARG_STATE
+	PROP_0,
+	PROP_STATE,
 };
 
 static guint e_table_config_signals [LAST_SIGNAL] = { 0, };
 
 static void
-config_destroy (GtkObject *object)
+config_finalize (GObject *object)
 {
 	ETableConfig *config = E_TABLE_CONFIG (object);
 
-	gtk_object_destroy (GTK_OBJECT (config->state));
-	gtk_object_unref (GTK_OBJECT (config->source_state));
-	gtk_object_unref (GTK_OBJECT (config->source_spec));
+	if (config->state)
+		g_object_unref (config->state);
+	config->state = NULL;
+
+	if (config->source_state)
+		g_object_unref (config->source_state);
+	config->source_state = NULL;
+
+	if (config->source_spec)
+		g_object_unref (config->source_spec);
+	config->source_spec = NULL;
+
 	g_free (config->header);
 	config->header = NULL;
 
@@ -82,23 +87,8 @@ config_destroy (GtkObject *object)
 
 	g_free (config->domain);
 	config->domain = NULL;
-	
-	GTK_OBJECT_CLASS (config_parent_class)->destroy (object);
-}
 
-static void
-config_get_arg (GtkObject *o, GtkArg *arg, guint arg_id)
-{
-	ETableConfig *config = E_TABLE_CONFIG (o);
-
-	switch (arg_id){
-	case ARG_STATE:
-		GTK_VALUE_OBJECT (*arg) = (GtkObject *) config->state;
-		break;
-
-	default:
-		break;
-	}
+	config_parent_class->finalize (object);
 }
 
 static void
@@ -108,37 +98,65 @@ e_table_config_changed (ETableConfig *config, ETableState *state)
 	g_return_if_fail (E_IS_TABLE_CONFIG (config));
 
 	
-	gtk_signal_emit(GTK_OBJECT(config),
-			e_table_config_signals [CHANGED],
-			state);
+	g_signal_emit(G_OBJECT(config), e_table_config_signals [CHANGED], 0, state);
 }
 
 static void
-config_class_init (GtkObjectClass *object_class)
+config_dialog_changed (ETableConfig *config)
+{
+	/* enable the apply/ok buttons */
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (config->dialog_toplevel),
+					   GTK_RESPONSE_APPLY, TRUE);
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (config->dialog_toplevel),
+					   GTK_RESPONSE_OK, TRUE);
+}
+
+static void
+config_get_property (GObject *object,
+		     guint prop_id,
+		     GValue *value,
+		     GParamSpec *pspec)
+{
+	ETableConfig *config = E_TABLE_CONFIG (object);
+
+	switch (prop_id) {
+	case PROP_STATE:
+		g_value_set_object (value, config->state);
+		break;
+	default:
+		break;
+	}
+}
+
+static void
+config_class_init (GObjectClass *object_class)
 {
 	ETableConfigClass *klass = E_TABLE_CONFIG_CLASS(object_class);
 
-	config_parent_class   = gtk_type_class (PARENT_TYPE);
+	config_parent_class   = g_type_class_peek_parent (klass);
 	
 	klass->changed        = NULL;
 
-	object_class->get_arg = config_get_arg;
-	object_class->destroy = config_destroy;
+	object_class->finalize = config_finalize;
+	object_class->get_property = config_get_property;
 
 	e_table_config_signals [CHANGED] =
-		gtk_signal_new ("changed",
-				GTK_RUN_LAST,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (ETableConfigClass, changed),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
+		g_signal_new ("changed",
+			      E_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (ETableConfigClass, changed),
+			      (GSignalAccumulator) NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
 
-	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_table_config_signals, LAST_SIGNAL);
+	g_object_class_install_property (object_class, PROP_STATE,
+					 g_param_spec_object ("state",
+							      _("State"),
+							      /*_( */"XXX blurb" /*)*/,
+							      E_TABLE_STATE_TYPE,
+							      G_PARAM_READABLE));
 
-	gtk_object_add_arg_type ("ETableConfig::state", E_TABLE_STATE_TYPE,
-				 GTK_ARG_READABLE, ARG_STATE);
-
-	glade_gnome_init ();
+	glade_init ();
 }
 
 static ETableColumnSpecification *
@@ -198,11 +216,11 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		/*
 		 * Sorting is set, auto select the text
 		 */
-		gtk_signal_handler_block (
-			GTK_OBJECT (widgets [i].radio_ascending),
+		g_signal_handler_block (
+			widgets [i].radio_ascending,
 			widgets [i].toggled_id);
-		gtk_signal_handler_block (
-			GTK_OBJECT (widgets [i].combo->entry),
+		g_signal_handler_block (
+			widgets [i].combo->entry,
 			widgets [i].changed_id);
 		
 		if (i < count){
@@ -256,11 +274,11 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		/* Set the text */
 		gtk_combo_text_set_text (widgets [i].combo, text);
 
-		gtk_signal_handler_unblock (
-			GTK_OBJECT (widgets [i].radio_ascending),
+		g_signal_handler_unblock (
+			widgets [i].radio_ascending,
 			widgets [i].toggled_id);
-		gtk_signal_handler_unblock (
-			GTK_OBJECT (widgets [i].combo->entry),
+		g_signal_handler_unblock (
+			widgets [i].combo->entry,
 			widgets [i].changed_id);
 	}
 }
@@ -355,7 +373,7 @@ setup_fields (ETableConfig *config)
 	if (config->temp_state) {
 		for (i = 0; i < config->temp_state->col_count; i++) {
 			e_table_subset_variable_add (config->shown_model, config->temp_state->columns[i]);
-			e_table_without_hide (config->available_model, (void *) config->temp_state->columns[i]);
+			e_table_without_hide (config->available_model, GINT_TO_POINTER(config->temp_state->columns[i]));
 		}
 	}
 }
@@ -389,8 +407,8 @@ config_fields_info_update (ETableConfig *config)
 static void
 do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 {
-	GnomeDialog *dialog;
-	int button, running = 1;
+	GtkDialog *dialog;
+	int response, running = 1;
 
 	config->temp_state = e_table_state_duplicate (config->state);
 
@@ -403,14 +421,16 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		
 
 	if (is_sort)
-		dialog = GNOME_DIALOG (config->dialog_sort);
+		dialog = GTK_DIALOG (config->dialog_sort);
 	else
-		dialog = GNOME_DIALOG (config->dialog_group_by);
+		dialog = GTK_DIALOG (config->dialog_group_by);
 	
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (config->dialog_toplevel));
+
 	do {
-		button = gnome_dialog_run (dialog);
-		switch (button){
-		case 0:
+		response = gtk_dialog_run (dialog);
+		switch (response){
+		case 0: /* clear fields */
 			if (is_sort){
 				e_table_sort_info_sorting_truncate (
 					config->temp_state->sort_info, 0);
@@ -421,27 +441,24 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 			update_sort_and_group_config_dialog (config, is_sort);
 			continue;
 
-			/* OK */
-		case 1:
-			gtk_object_unref (GTK_OBJECT (config->state));
+		case GTK_RESPONSE_OK:
+			g_object_unref (config->state);
 			config->state = config->temp_state;
 			config->temp_state = 0;
 			running = 0;
-			gnome_property_box_changed (
-				GNOME_PROPERTY_BOX (config->dialog_toplevel));
+			config_dialog_changed (config);
 			break;
 
-			/* CANCEL */
-		case 2:
-			gtk_object_unref (GTK_OBJECT (config->temp_state));
+		case GTK_RESPONSE_CANCEL:
+			g_object_unref (config->temp_state);
 			config->temp_state = 0;
 			running = 0;
 			break;
 		}
 		
 	} while (running);
-	gnome_dialog_close (GNOME_DIALOG (dialog));
-
+	gtk_widget_hide (GTK_WIDGET (dialog));
+	
 	if (is_sort)
 		config_sort_info_update (config);
 	else
@@ -451,35 +468,36 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 static void
 do_fields_config_dialog (ETableConfig *config)
 {
-	int button, running = 1;
+	int response, running = 1;
 
 	config->temp_state = e_table_state_duplicate (config->state);
 
 	setup_fields (config);
 
+	gtk_window_set_transient_for (GTK_WINDOW (config->dialog_show_fields),
+				      GTK_WINDOW (config->dialog_toplevel));
+
 	do {
-		button = gnome_dialog_run (GNOME_DIALOG(config->dialog_show_fields));
-		switch (button){
-			/* OK */
-		case 0:
-			gtk_object_unref (GTK_OBJECT (config->state));
+		response = gtk_dialog_run (GTK_DIALOG(config->dialog_show_fields));
+		switch (response){
+		case GTK_RESPONSE_OK:
+			g_object_unref (config->state);
 			config->state = config->temp_state;
 			config->temp_state = 0;
 			running = 0;
-			gnome_property_box_changed (
-				GNOME_PROPERTY_BOX (config->dialog_toplevel));
+			config_dialog_changed (config);
 			break;
 
 			/* CANCEL */
-		case 1:
-			gtk_object_unref (GTK_OBJECT (config->temp_state));
+		case GTK_RESPONSE_CANCEL:
+			g_object_unref (config->temp_state);
 			config->temp_state = 0;
 			running = 0;
 			break;
 		}
 		
 	} while (running);
-	gnome_dialog_close (GNOME_DIALOG (config->dialog_show_fields));
+	gtk_widget_hide (GTK_WIDGET (config->dialog_show_fields));
 
 	config_fields_info_update (config);
 }
@@ -499,7 +517,7 @@ create_global_store (ETableConfig *config)
 
 	global_store = e_table_memory_store_new (store_columns);
 	for (i = 0; config->source_spec->columns[i]; i++) {
-		char *text = e_utf8_from_locale_string (dgettext (config->domain,
+		char *text = g_strdup (dgettext (config->domain,
 								  config->source_spec->columns[i]->title));
 
 		e_table_memory_store_insert_adopt (E_TABLE_MEMORY_STORE (global_store), i, NULL, text);
@@ -560,19 +578,25 @@ config_button_group (GtkWidget *widget, ETableConfig *config)
 }
 
 static void
-dialog_destroyed (GtkObject *dialog, ETableConfig *config)
+dialog_destroyed (gpointer data, GObject *where_object_was)
 {
-	gtk_object_destroy (GTK_OBJECT (config));
+	ETableConfig *config = data;
+	g_object_unref (config);
 }
 
 static void
-dialog_apply (GnomePropertyBox *pbox, gint page_num, ETableConfig *config)
+dialog_response (GtkWidget *dialog, int response_id, ETableConfig *config)
 {
-	if (page_num != -1)
-		return;
+	if (response_id == GTK_RESPONSE_APPLY
+	    || response_id == GTK_RESPONSE_OK) {
+		e_table_config_changed (config, config->state);
+	}
 
-	e_table_config_changed (config, config->state);
-}
+	if (response_id == GTK_RESPONSE_CANCEL
+	    || response_id == GTK_RESPONSE_OK) {
+		gtk_widget_destroy (dialog);
+	}
+}	
 
 /*
  * Invoked by the Glade auto-connect code
@@ -597,13 +621,13 @@ configure_dialog (GladeXML *gui, const char *widget_name, ETableConfig *config)
 #endif
 
 static void
-connect_button (ETableConfig *config, GladeXML *gui, const char *widget_name, GtkSignalFunc cback)
+connect_button (ETableConfig *config, GladeXML *gui, const char *widget_name, GCallback cback)
 {
 	GtkWidget *button = glade_xml_get_widget (gui, widget_name);
 
 	if (button) {
-		gtk_signal_connect (GTK_OBJECT (button), "clicked",
-				    cback, config);
+		g_signal_connect (G_OBJECT (button), "clicked",
+				  cback, config);
 	}
 }
 
@@ -615,7 +639,7 @@ sort_entry_changed (GtkEntry *entry, ETableConfigSortWidgets *sort)
 	ETableConfigSortWidgets *base = &config->sort[0];
 	int idx = sort - base;
 	
-	char *s = gtk_entry_get_text (entry);
+	const char *s = gtk_entry_get_text (entry);
 
 	if (s && s [0] && g_hash_table_lookup (sort->combo->elements, s)){
 		ETableSortColumn c;
@@ -665,7 +689,7 @@ configure_sort_dialog (ETableConfig *config, GladeXML *gui)
 		snprintf (buffer, sizeof (buffer), "sort-combo-%d", i + 1);
 		config->sort [i].combo = GTK_COMBO_TEXT (
 			glade_xml_get_widget (gui, buffer));
-
+		gtk_widget_show (GTK_WIDGET (config->sort [i].combo));
 		gtk_combo_text_add_item (config->sort [i].combo, "", "");
 
 		snprintf (buffer, sizeof (buffer), "frame-sort-%d", i + 1);
@@ -700,13 +724,15 @@ configure_sort_dialog (ETableConfig *config, GladeXML *gui)
 	 * After we have runtime modified things, signal connect
 	 */
 	for (i = 0; i < 4; i++){
-		config->sort [i].changed_id = gtk_signal_connect (
-			GTK_OBJECT (config->sort [i].combo->entry),
-			"changed", sort_entry_changed, &config->sort [i]);
+		config->sort [i].changed_id = g_signal_connect (
+			config->sort [i].combo->entry,
+			"changed", G_CALLBACK (sort_entry_changed),
+			&config->sort [i]);
 
-		config->sort [i].toggled_id = gtk_signal_connect (
-			GTK_OBJECT (config->sort [i].radio_ascending),
-			"toggled", sort_ascending_toggled, &config->sort [i]);
+		config->sort [i].toggled_id = g_signal_connect (
+			config->sort [i].radio_ascending,
+			"toggled", G_CALLBACK (sort_ascending_toggled),
+			&config->sort [i]);
 	}
 }
 
@@ -717,7 +743,7 @@ group_entry_changed (GtkEntry *entry, ETableConfigSortWidgets *group)
 	ETableSortInfo *sort_info = config->temp_state->sort_info;
 	ETableConfigSortWidgets *base = &config->group[0];
 	int idx = group - base;
-	char *s = gtk_entry_get_text (entry);
+	const char *s = gtk_entry_get_text (entry);
 
 	if (s && s [0] && g_hash_table_lookup (group->combo->elements, s)){
 		ETableSortColumn c;
@@ -767,6 +793,7 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 		snprintf (buffer, sizeof (buffer), "group-combo-%d", i + 1);
 		config->group [i].combo = GTK_COMBO_TEXT (
 			glade_xml_get_widget (gui, buffer));
+		gtk_widget_show (GTK_WIDGET (config->group [i].combo));
 
 		gtk_combo_text_add_item (config->group [i].combo, "", "");
 
@@ -810,13 +837,15 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 	 * After we have runtime modified things, signal connect
 	 */
 	for (i = 0; i < 4; i++){
-		config->group [i].changed_id = gtk_signal_connect (
-			GTK_OBJECT (config->group [i].combo->entry),
-			"changed", group_entry_changed, &config->group [i]);
+		config->group [i].changed_id = g_signal_connect (
+			config->group [i].combo->entry,
+			"changed", G_CALLBACK (group_entry_changed),
+			&config->group [i]);
 
-		config->group [i].toggled_id = gtk_signal_connect (
-			GTK_OBJECT (config->group [i].radio_ascending),
-			"toggled", group_ascending_toggled, &config->group [i]);
+		config->group [i].toggled_id = g_signal_connect (
+			config->group [i].radio_ascending,
+			"toggled", G_CALLBACK (group_ascending_toggled),
+			&config->group [i]);
 	}
 }
 
@@ -980,20 +1009,26 @@ config_button_down (GtkWidget *widget, ETableConfig *config)
 static void
 configure_fields_dialog (ETableConfig *config, GladeXML *gui)
 {
-	config->available = e_table_scrolled_get_table (E_TABLE_SCROLLED (glade_xml_get_widget (gui, "custom-available")));
-	gtk_object_get (GTK_OBJECT (config->available),
-			"model", &config->available_model,
-			NULL);
+	GtkWidget *scrolled;
 
-	config->shown = e_table_scrolled_get_table (E_TABLE_SCROLLED (glade_xml_get_widget (gui, "custom-shown")));
-	gtk_object_get (GTK_OBJECT (config->shown),
-			"model", &config->shown_model,
-			NULL);
+	scrolled = glade_xml_get_widget (gui, "custom-available");
+	config->available = e_table_scrolled_get_table (E_TABLE_SCROLLED (scrolled));
+	g_object_get (config->available,
+		      "model", &config->available_model,
+		      NULL);
+	gtk_widget_show_all (scrolled);
 
-	connect_button (config, gui, "button-add",    config_button_add);
-	connect_button (config, gui, "button-remove", config_button_remove);
-	connect_button (config, gui, "button-up",     config_button_up);
-	connect_button (config, gui, "button-down",   config_button_down);
+	scrolled = glade_xml_get_widget (gui, "custom-shown");
+	config->shown = e_table_scrolled_get_table (E_TABLE_SCROLLED (scrolled));
+	g_object_get (config->shown,
+		      "model", &config->shown_model,
+		      NULL);
+	gtk_widget_show_all (scrolled);
+
+	connect_button (config, gui, "button-add",    G_CALLBACK (config_button_add));
+	connect_button (config, gui, "button-remove", G_CALLBACK (config_button_remove));
+	connect_button (config, gui, "button-up",     G_CALLBACK (config_button_up));
+	connect_button (config, gui, "button-down",   G_CALLBACK (config_button_down));
 
 	setup_fields (config);
 }
@@ -1006,12 +1041,12 @@ setup_gui (ETableConfig *config)
 	create_global_store (config);
 
 	if (e_table_sort_info_get_can_group (config->state->sort_info)) {
-		gui = glade_xml_new_with_domain (ETABLE_GLADEDIR "/e-table-config.glade", NULL, E_I18N_DOMAIN);
+		gui = glade_xml_new (ETABLE_GLADEDIR "/e-table-config.glade", NULL, E_I18N_DOMAIN);
 	} else {
-		gui = glade_xml_new_with_domain (ETABLE_GLADEDIR "/e-table-config-no-group.glade", NULL, E_I18N_DOMAIN);
+		gui = glade_xml_new (ETABLE_GLADEDIR "/e-table-config-no-group.glade", NULL, E_I18N_DOMAIN);
 	}
 
-	gtk_object_unref (GTK_OBJECT (global_store));
+	g_object_unref (global_store);
 	
 	config->dialog_toplevel = glade_xml_get_widget (
 		gui, "e-table-config");
@@ -1019,13 +1054,6 @@ setup_gui (ETableConfig *config)
 	if (config->header)
 		gtk_window_set_title (GTK_WINDOW (config->dialog_toplevel), config->header);
 
-	gtk_widget_hide (GNOME_PROPERTY_BOX(config->dialog_toplevel)->help_button);
-
-	gtk_notebook_set_show_tabs (
-		GTK_NOTEBOOK (GNOME_PROPERTY_BOX (
-			config->dialog_toplevel)->notebook),
-		FALSE);
-	
 	config->dialog_show_fields = glade_xml_get_widget (
 		gui, "dialog-show-fields");
 	config->dialog_group_by =  glade_xml_get_widget (
@@ -1040,23 +1068,21 @@ setup_gui (ETableConfig *config)
 	config->fields_label = glade_xml_get_widget (
 		gui, "label-fields");
 
-	connect_button (config, gui, "button-sort", config_button_sort);
-	connect_button (config, gui, "button-group", config_button_group);
-	connect_button (config, gui, "button-fields", config_button_fields);
+	connect_button (config, gui, "button-sort", G_CALLBACK (config_button_sort));
+	connect_button (config, gui, "button-group", G_CALLBACK (config_button_group));
+	connect_button (config, gui, "button-fields", G_CALLBACK (config_button_fields));
 	
 	configure_sort_dialog (config, gui);
 	configure_group_dialog (config, gui);
 	configure_fields_dialog (config, gui);
-	
-	gtk_signal_connect (
-		GTK_OBJECT (config->dialog_toplevel), "destroy",
-		GTK_SIGNAL_FUNC (dialog_destroyed), config);
 
-	gtk_signal_connect (
-		GTK_OBJECT (config->dialog_toplevel), "apply",
-		GTK_SIGNAL_FUNC (dialog_apply), config);
+	g_object_weak_ref (G_OBJECT (config->dialog_toplevel),
+			   dialog_destroyed, config);
 
-	gtk_object_unref (GTK_OBJECT (gui));
+	g_signal_connect (config->dialog_toplevel, "response",
+			  G_CALLBACK (dialog_response), config);
+
+	g_object_unref (gui);
 }
 
 static void
@@ -1069,7 +1095,8 @@ ETableConfig *
 e_table_config_construct (ETableConfig        *config,
 			  const char          *header,
 			  ETableSpecification *spec,
-			  ETableState         *state)
+			  ETableState         *state,
+			  GtkWindow           *parent_window)
 {
 	ETableColumnSpecification **column;
 
@@ -1082,8 +1109,8 @@ e_table_config_construct (ETableConfig        *config,
 	config->source_state = state;
 	config->header = g_strdup (header);
 
-	gtk_object_ref (GTK_OBJECT (config->source_spec));
-	gtk_object_ref (GTK_OBJECT (config->source_state));
+	g_object_ref (config->source_spec);
+	g_object_ref (config->source_state);
 
 	config->state = e_table_state_duplicate (state);
 
@@ -1101,6 +1128,10 @@ e_table_config_construct (ETableConfig        *config,
 
 	setup_gui (config);
 
+	if (parent_window)
+		gtk_window_set_transient_for (GTK_WINDOW (config->dialog_toplevel),
+					      parent_window);
+
 	config_sort_info_update   (config);
 	config_group_info_update  (config);
 	config_fields_info_update (config);
@@ -1121,12 +1152,13 @@ e_table_config_construct (ETableConfig        *config,
 ETableConfig *
 e_table_config_new (const char          *header,
 		    ETableSpecification *spec,
-		    ETableState         *state)
+		    ETableState         *state,
+		    GtkWindow           *parent_window)
 {
-	ETableConfig *config = gtk_type_new (E_TABLE_CONFIG_TYPE);
+	ETableConfig *config = g_object_new (E_TABLE_CONFIG_TYPE, NULL);
 
-	if (e_table_config_construct (config, header, spec, state) == NULL){
-		gtk_object_destroy (GTK_OBJECT (config));
+	if (e_table_config_construct (config, header, spec, state, parent_window) == NULL){
+		g_object_unref (config);
 		return NULL;
 	}
 
@@ -1146,4 +1178,4 @@ e_table_config_raise (ETableConfig *config)
 	gdk_window_raise (GTK_WIDGET (config->dialog_toplevel)->window);
 }
 
-E_MAKE_TYPE(e_table_config, "ETableConfig", ETableConfig, config_class_init, config_init, PARENT_TYPE)
+E_MAKE_TYPE(e_table_config, "ETableConfig", ETableConfig, config_class_init, config_init, G_TYPE_OBJECT)
